@@ -20,11 +20,11 @@
 
 #include "DBusHelperProxy.h"
 
-#include <QtCore/qplugin.h>
+#include <qplugin.h>
 #include <QObject>
 #include <QMap>
-#include <QtDBus/QDBusMessage>
-#include <QtDBus/QDBusConnection>
+#include <QDBusMessage>
+#include <QDBusConnection>
 #include <QTimer>
 
 #include "BackendsManager.h"
@@ -304,7 +304,7 @@ void DBusHelperProxy::sendProgressStep(const QVariantMap &data)
 
 void debugMessageReceived(int t, const QString &message)
 {
-    QtMsgType type = (QtMsgType)t;
+    QtMsgType type = static_cast<QtMsgType>(t);
     switch (type) {
     case QtDebugMsg:
         qDebug("Debug message from helper: %s", message.toLatin1().data());
