@@ -21,20 +21,21 @@
 
 #include "Polkit1Backend.h"
 
-#include <QtCore/qplugin.h>
-#include <QtCore/QCoreApplication>
-#include <QtCore/QDebug>
-#include <QtCore/QTimer>
+#include <qplugin.h>
+#include <QCoreApplication>
+#include <QTimer>
 
 #include <QApplication>
 #include <QWidget>
 
-#include <QtDBus/QDBusConnection>
-#include <QtDBus/QDBusConnectionInterface>
+#include <QDBusConnection>
+#include <QDBusConnectionInterface>
 
 #include <PolkitQt1/Authority>
 #include <PolkitQt1/Subject>
 
+#include "kauthdebug.h"
+
 namespace KAuth
 {
 
@@ -86,15 +87,15 @@ void Polkit1Backend::preAuthAction(const QString &action, QWidget *parent)
 {
     // If a parent was not specified, skip this
     if (!parent) {
-        qDebug() << "Parent widget does not exist, skipping";
+        qCDebug(KAUTH) << "Parent widget does not exist, skipping";
         return;
     }
 
     // Are we running our KDE auth agent?
-    if (QDBusConnection::sessionBus().interface()->isServiceRegistered(QLatin1String("org.kde.Polkit1AuthAgent"))) {
+    if (QDBusConnection::sessionBus().interface()->isServiceRegistered(QLatin1String("org.kde.polkit-kde-authentication-agent-1"))) {
         // Check if we actually are entitled to use GUI capabilities
         if (qApp == 0 || !qobject_cast<QApplication *>(qApp)) {
-            qDebug() << "Not streaming parent as we are on a TTY application";
+            qCDebug(KAUTH) << "Not streaming parent as we are on a TTY application";
         }
 
         // Retrieve the dialog root window Id
@@ -102,7 +103,7 @@ void Polkit1Backend::preAuthAction(const QString &action, QWidget *parent)
 
         // Send it over the bus to our agent
         QDBusMessage methodCall =
-            QDBusMessage::createMethodCall(QLatin1String("org.kde.Polkit1AuthAgent"), QLatin1String("/org/kde/Polkit1AuthAgent"), QLatin1String("org.kde.Polkit1AuthAgent"),
+            QDBusMessage::createMethodCall(QLatin1String("org.kde.polkit-kde-authentication-agent-1"), QLatin1String("/org/kde/Polkit1AuthAgent"), QLatin1String("org.kde.Polkit1AuthAgent"),
                                            QLatin1String("setWIdForAction"));
 
         methodCall << action;
@@ -112,10 +113,10 @@ void Polkit1Backend::preAuthAction(const QString &action, QWidget *parent)
         call.waitForFinished();
 
         if (call.isError()) {
-            qWarning() << "ERROR while streaming the parent!!" << call.error();
+            qCWarning(KAUTH) << "ERROR while streaming the parent!!" << call.error();
         }
     } else {
-        qDebug() << "KDE polkit agent appears too old or not registered on the bus";
+        qCDebug(KAUTH) << "KDE polkit agent appears too old or not registered on the bus";
     }
 }
 
@@ -142,9 +143,16 @@ void Polkit1Backend::setupAction(const QString &action)
 
 Action::AuthStatus Polkit1Backend::actionStatus(const QString &action)
 {
-    PolkitQt1::UnixProcessSubject subject(QCoreApplication::applicationPid());
-    PolkitQt1::Authority::Result r = PolkitQt1::Authority::instance()->checkAuthorizationSync(action, subject,
+    PolkitQt1::SystemBusNameSubject subject(QString::fromUtf8(callerID()));
+    auto authority = PolkitQt1::Authority::instance();
+    PolkitQt1::Authority::Result r = authority->checkAuthorizationSync(action, subject,
                                      PolkitQt1::Authority::None);
+
+    if (authority->hasError()) {
+        qCDebug(KAUTH) << "Encountered error while checking action status, error code:" << authority->lastError() << authority->errorDetails();
+        authority->clearError();
+    }
+
     switch (r) {
     case PolkitQt1::Authority::Yes:
         return Action::AuthorizedStatus;
@@ -158,21 +166,17 @@ Action::AuthStatus Polkit1Backend::actionStatus(const QString &action)
 
 QByteArray Polkit1Backend::callerID() const
 {
-    QByteArray a;
-    QDataStream s(&a, QIODevice::WriteOnly);
-    s << QCoreApplication::applicationPid();
+        return QDBusConnection::systemBus().baseService().toUtf8();
+}
 
-    return a;
+AuthBackend::ExtraCallerIDVerificationMethod Polkit1Backend::extraCallerIDVerificationMethod() const
+{
+    return VerifyAgainstDBusServiceName;
 }
 
 bool Polkit1Backend::isCallerAuthorized(const QString &action, QByteArray callerID)
 {
-    QDataStream s(&callerID, QIODevice::ReadOnly);
-    qint64 pid;
-
-    s >> pid;
-
-    PolkitQt1::UnixProcessSubject subject(pid);
+    PolkitQt1::SystemBusNameSubject subject(QString::fromUtf8(callerID));
     PolkitQt1::Authority *authority = PolkitQt1::Authority::instance();
 
     PolkitResultEventLoop e;
@@ -181,6 +185,11 @@ bool Polkit1Backend::isCallerAuthorized(const QString &action, QByteArray caller
     authority->checkAuthorization(action, subject, PolkitQt1::Authority::AllowUserInteraction);
     e.exec();
 
+    if (authority->hasError()) {
+        qCDebug(KAUTH) << "Encountered error while checking authorization, error code:" << authority->lastError() << authority->errorDetails();
+        authority->clearError();
+    }
+
     switch (e.result()) {
     case PolkitQt1::Authority::Yes:
         return true;
@@ -207,6 +216,14 @@ void Polkit1Backend::checkForResultChanged()
 
 bool Polkit1Backend::actionExists(const QString &action)
 {
+    auto authority = PolkitQt1::Authority::instance();
+    if (m_flyingActions && authority->hasError()) {
+            // This can happen if enumerateActions call failed
+            qWarning() << "Encountered error while enumerating actions, error code:" << authority->lastError() << authority->errorDetails();
+            authority->clearError();
+            m_flyingActions = false;
+    }
+
     // Any flying actions?
     if (m_flyingActions) {
         int tries = 0;
